<?php
/**
 * Oficina de Suport theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Oficina_de_Suport_theme
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.1' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ofisuport_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Oficina de Suport theme, use a find and replace
		* to change 'ofisuport' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'ofisuport', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
//	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu()
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'ofisuport' ),
			'menu-2' => esc_html__( 'Secondary', 'ofisuport' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	//
	//add_theme_support(
	//	'custom-background',
	//	apply_filters(
	//		'ofisuport_custom_background_args',
	//		array(
	//			'default-color' => 'ffffff',
	//			'default-image' => '',
	//		)
	//	)
	//);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 252,
			'width'       => 125,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'ofisuport_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ofisuport_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ofisuport_content_width', 640 );
}
add_action( 'after_setup_theme', 'ofisuport_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */

require get_template_directory() . '/inc/widgets-register.php';

/**
 * Enqueue scripts and styles.
 */
function ofisuport_scripts() {
	wp_enqueue_style( 'ofisuport-style', get_stylesheet_uri(), array(), _S_VERSION );
  //https://developer.wordpress.org/reference/functions/wp_enqueue_style/#comment-2056
  //wp_enqueue_style('main-styles', get_template_directory_uri() . '/css/style.css', array(), filemtime(get_template_directory() . '/css/style.css'), false);
	//wp_enqueue_style( 'ofisuport-style', get_stylesheet_uri(), array(), filemtime(get_stylesheet_uri() . 'style.css'), false);
	wp_style_add_data( 'ofisuport-style', 'rtl', 'replace' );

	wp_enqueue_script( 'ofisuport-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ofisuport_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Functions to personalize login screen 
 */
require get_template_directory() . '/inc/login-functions.php';

/**
 * Functions to personalize the_archive_title() function
 */

require get_template_directory() . '/inc/archive-title.php';

/**
 * Functions to add admin styles
 */
require get_template_directory() . '/inc/admin-style.php';

/**
 * Function to add filter in ofisuport-ajut custom post
 */
  // moved to plugin on 2023 01 05
//require get_template_directory() . '/inc/ofisuport-ajut-filter.php';
